@@ -4,62 +4,62 @@
 <context>
     <name>ConfigWindow</name>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="601"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="603"/>
         <source>Keep backlight on</source>
         <translation type="unfinished">Beeld niet dimmen</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="603"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="605"/>
         <source>Wakeup screen on alarm</source>
         <translation type="unfinished">Scherm aan bij alarm</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="604"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="606"/>
         <source>Vibrate on alarm</source>
         <translation type="unfinished">Tril bij alarm</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="605"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="607"/>
         <source>Sound on alarm</source>
         <translation type="unfinished">Geluid bij alarm</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="606"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="608"/>
         <source>Alarm banner</source>
         <translation type="unfinished">Alarm tekst</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="627"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="629"/>
         <source>Done</source>
         <translation type="unfinished">Opslaan</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="639"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="641"/>
         <source>Alarm volume: </source>
         <translation type="unfinished">Alarm volume:</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="653"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="655"/>
         <source>Alarm volume: max</source>
         <translation type="unfinished">Alarm volume: max</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="642"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="644"/>
         <source>Alarm muted</source>
         <translation type="unfinished">Stil alarm</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="683"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="685"/>
         <source>Configuration is successfully saved</source>
         <translation type="unfinished">Configuratie is succesvol opgeslagen</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="688"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="690"/>
         <source>Could NOT save Configuration!</source>
         <translation type="unfinished">Configuratie kon niet worden opgeslagen!</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="587"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="589"/>
         <source>Configuration cooktimer</source>
         <translation type="unfinished">Configuratie cooktimer</translation>
     </message>
@@ -67,7 +67,7 @@
 <context>
     <name>DishPickDialog</name>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2611"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2695"/>
         <source>[Choose dish]</source>
         <translation type="unfinished">[Kies gerecht]</translation>
     </message>
@@ -75,52 +75,52 @@
 <context>
     <name>FormWidget</name>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2152"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2236"/>
         <source>timer 2 ready!</source>
         <translation type="unfinished">timer 2 klaar!</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2239"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2323"/>
         <source>Start</source>
         <translation type="unfinished">Start</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="1824"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="1896"/>
         <source>Choose dish</source>
         <translation type="unfinished">Kies gerecht</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2073"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2157"/>
         <source>timer 1 ready!</source>
         <translation type="unfinished">timer 1 klaar!</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2230"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2314"/>
         <source>timer 3 ready!</source>
         <translation type="unfinished">timer 3 klaar!</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2004"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2088"/>
         <source>Stop</source>
         <translation type="unfinished">Stop</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="1515"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="1578"/>
         <source>Stopwatch mode ON</source>
         <translation type="unfinished">Stopwatch mode AAN</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="1534"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="1597"/>
         <source>Stopwatch mode OFF</source>
         <translation type="unfinished">Stopwatch mode UIT</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="1639"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="1708"/>
         <source>Continue mode ON</source>
         <translation type="unfinished">Vervolg mode AAN</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="1644"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="1716"/>
         <source>Continue mode OFF</source>
         <translation type="unfinished">Vervolg mode UIT</translation>
     </message>
@@ -128,57 +128,57 @@
 <context>
     <name>HelpWindow</name>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="535"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="537"/>
         <source>Help</source>
         <translation type="unfinished">Help</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="552"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="554"/>
         <source>Cooktimer</source>
         <translation type="unfinished">Cooktimer</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="555"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="557"/>
         <source>Apart from the obvious functions and settings, there are some not so easily spotted:</source>
         <translation type="unfinished">Naast de vanzelfsprekende functies en instellingen, zijn er een aantal niet zo makkelijk te herkennen:</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="557"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="559"/>
         <source>Pressing a running timer bar will pause the alarm</source>
         <translation type="unfinished">Het aanraken van de tijdsbalk zal de klok pauzeren</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="558"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="560"/>
         <source>Pressing a paused timer bar will unpause the alarm</source>
         <translation type="unfinished">Het aanraken van de gepauzeerde tijdsbalk zal de klok hervatten</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="559"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="561"/>
         <source>Pressing a timer bar after showing &quot;00:00:00&quot; will silence it&apos;s alarm</source>
         <translation type="unfinished">Door op de tijdsbalk te drukken waarbij het alarm afgaat, zal het alarmsignaal stoppen</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="563"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="565"/>
         <source>By pushing the add icon in the &quot;edit dishes&quot; menu you can set interim messages and make it preload at startup</source>
         <translation type="unfinished">Via het plus icoon in &quot;Bewerk gerechten&quot; kan men tussentijdse berichten zetten en automatisch met het gerecht opstarten</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="553"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="555"/>
         <source>Cooktimer provides three timers for preparing the perfect meal.</source>
         <translation type="unfinished">Cooktimer biedt drie timers om een perfecte maaltijd te bereiden.</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="560"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="562"/>
         <source>Long-pressing a dishpicker will reset all dish settings</source>
         <translation type="unfinished">Het lang indrukken van de gerechtknop zal alle gerechtinstellingen resetten</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="561"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="563"/>
         <source>Long-pressing a timepicker will toggle continue mode</source>
         <translation type="unfinished">Het lang indrukken van de tijd keuzetoets zal de vervolgmode aan of uit zetten</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="562"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="564"/>
         <source>Long-pressing a timer bar will toggle stopwatch mode</source>
         <translation type="unfinished">Het lang indrukken van de tijdsbalk zal de stopwatchmode aan of uit zetten</translation>
     </message>
@@ -186,75 +186,80 @@
 <context>
     <name>MyMainWindow</name>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="376"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="377"/>
         <source>&amp;About</source>
         <translation type="unfinished">&amp;Over</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="339"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="340"/>
         <source>&amp;Landscape</source>
         <translation type="unfinished">&amp;Landschap</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="341"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="342"/>
         <source>&amp;Portrait</source>
         <translation type="unfinished">&amp;Portret</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="343"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="344"/>
         <source>&amp;Autorotate</source>
         <translation type="unfinished">&amp;Autorotatie</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="349"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="350"/>
         <source>&amp;Settings</source>
         <translation type="unfinished">&amp;Instellingen</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="373"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="374"/>
         <source>&amp;Edit dishes</source>
         <translation type="unfinished">&amp;Bewerk gerechten</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="374"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="375"/>
         <source>&amp;Custom alarm sound</source>
         <translation type="unfinished">&amp;Alarm geluid</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="524"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="525"/>
         <source>About</source>
         <translation type="unfinished">Over</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="527"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="528"/>
         <source>Created by</source>
         <translation type="unfinished">Gemaakt door</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="485"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="486"/>
         <source>Configuration is successfully saved</source>
         <translation type="unfinished">Configuratie is succesvol opgeslagen</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="490"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="491"/>
         <source>Could NOT save Configuration!</source>
         <translation type="unfinished">Configuratie kon niet worden opgeslagen!</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="375"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="376"/>
         <source>&amp;Help</source>
         <translation type="unfinished">&amp;Help</translation>
     </message>
+    <message>
+        <location filename="src/opt/cooktimer/cooktimer" line="529"/>
+        <source>Assistance by</source>
+        <translation type="unfinished">Assistentie van</translation>
+    </message>
 </context>
 <context>
     <name>TimePickDialog</name>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2464"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2548"/>
         <source>Done</source>
         <translation type="unfinished">Opslaan</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2463"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2547"/>
         <source>| hours | minutes | seconds |</source>
         <translation type="unfinished">| uren | minuten | seconden |</translation>
     </message>
@@ -262,42 +267,42 @@
 <context>
     <name>extItemWindow</name>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2711"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2795"/>
         <source>Message</source>
         <translation type="unfinished">Bericht</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2717"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2801"/>
         <source>time</source>
         <translation type="unfinished">tijd</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2755"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2839"/>
         <source>Done</source>
         <translation type="unfinished">Opslaan</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2702"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2786"/>
         <source>set on start</source>
         <translation type="unfinished">bij opstarten</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2750"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2834"/>
         <source>Alarm</source>
         <translation type="unfinished">Alarm</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2857"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2941"/>
         <source>Message time larger then alarm time!</source>
         <translation type="unfinished">Bericht na alarmtijd!</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2918"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="3002"/>
         <source>Max of 3 presets already used!</source>
         <translation type="unfinished">Max van 3 presets al gebruikt!</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2934"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="3018"/>
         <source>Messages are successfully saved</source>
         <translation type="unfinished">Berichten succesvol opgeslagen</translation>
     </message>
@@ -305,45 +310,53 @@
 <context>
     <name>fileWindow</name>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="985"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="987"/>
         <source>Choose soundfile</source>
         <translation type="unfinished">Kies geluidsfragment</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="1112"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="1121"/>
         <source>Configuration is successfully saved</source>
         <translation type="unfinished">Configuratie is succesvol opgeslagen</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="1117"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="1126"/>
         <source>Could NOT save Configuration!</source>
         <translation type="unfinished">Configuratie kon niet worden opgeslagen!</translation>
     </message>
 </context>
+<context>
+    <name>folderWindow</name>
+    <message>
+        <location filename="src/opt/cooktimer/cooktimer" line="1156"/>
+        <source>Select folder</source>
+        <translation type="unfinished">Kies map</translation>
+    </message>
+</context>
 <context>
     <name>itemWindow</name>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="772"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="774"/>
         <source>Dish cooktimes</source>
         <translation type="unfinished">Gerecht kooktijden</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="800"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="802"/>
         <source>Done</source>
         <translation type="unfinished">Opslaan</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="801"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="803"/>
         <source>New</source>
         <translation type="unfinished">Nieuw</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="949"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="951"/>
         <source>time</source>
         <translation type="unfinished">tijd</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="940"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="942"/>
         <source>Configuration is successfully saved</source>
         <translation type="unfinished">Configuratie is succesvol opgeslagen</translation>
     </message>
